==> kom%2B%2B-0.3.tar.gz: kom++-0.3/libkom++/uplink.h <==
// "Footn_to" and "comment_to" link objects.
//
// $Id: uplink.h,v 1.4 1994/07/16 17:47:52 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.

#ifndef UPLINK__
#define UPLINK__

#include <time.h>

#include "kom-types.h"
#include "misc.h"

class prot_a_LyStr;

class Uplink {
  public:
    Uplink();
    Uplink(const Uplink&);
    const Uplink &operator =(const Uplink &);

    int parse(Bool is_footnote, prot_a_LyStr &prot_a_str);

    Bool      is_footnote()const;
    Text_no   parent()     const;
    Pers_no   sender()     const;
    Bool      sent_later() const;
    struct tm sent_at()    const;
  private:
    enum { FOOTNOTE, COMMENT } upl_link_type;
    Text_no	upl_parent_text_no;
    Pers_no	upl_sender;	// 0 if not sent. Always 0 for FOOTNOTEs.
    Bool	upl_sent_later;
    struct tm	upl_sent_at;	// Only valid if sent_later is true.
};
#endif

==> kom%2B%2B-0.5.tar.gz: kom++-0.5/libkom++/uplink.h <==
// "Footn_to" and "comment_to" link objects.
//
// $Id: uplink.h,v 1.6 1995/11/18 22:50:35 ceder Exp $
// Copyright (C) 1994  Per Cederqvist and Inge Wallin
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
// 
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
// 
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.

#ifndef KOMXX_UPLINK_H
#define KOMXX_UPLINK_H

#include <time.h>

#include "kom-types.h"
#include "misc.h"

class prot_a_LyStr;

class Uplink {
  public:
    Uplink();
    Uplink(const Uplink&);
    const Uplink &operator =(const Uplink &);

    int parse(bool is_footnote, prot_a_LyStr &prot_a_str);

    bool      is_footnote()const;
    Text_no   parent()     const;
    Pers_no   sender()     const;
    bool      sent_later() const;
    struct tm sent_at()    const;
  private:
    enum { FOOTNOTE, COMMENT } upl_link_type;
    Text_no	upl_parent_text_no;
    Pers_no	upl_sender;	// 0 if not sent. Always 0 for FOOTNOTEs.
    bool	upl_sent_later;
    struct tm	upl_sent_at;	// Only valid if sent_later is true.
};
#endif
